@@ -9,7 +9,7 @@
 use crate::{
     attributes::{ObjectAttributesBuilder, SessionAttributesBuilder},
     constants::{tss::*, SessionType, Tss2ResponseCodeKind},
-    handles::{KeyHandle, SessionHandle},
+    handles::{KeyHandle, ObjectHandle, SessionHandle},
     interface_types::{
         algorithm::{HashingAlgorithm, PublicAlgorithm},
         ecc::EccCurve,
@@ -17,7 +17,7 @@ use crate::{
         resource_handles::Hierarchy,
     },
     structures::{
-        Auth, CreateKeyResult, Data, Digest, EccPoint, EccScheme, Public, PublicBuilder,
+        Auth, CreateKeyResult, Data, Digest, EccPoint, EccScheme, Name, Public, PublicBuilder,
         PublicEccParametersBuilder, PublicKeyRsa, PublicRsaParametersBuilder, RsaExponent,
         RsaScheme, Signature, SignatureScheme, SymmetricDefinitionObject, VerifiedTicket,
     },
@@ -137,6 +137,7 @@ impl TransientKeyContext {
     ///
     /// # Errors
     /// * if the authentication size is larger than 32 a `WrongParamSize` wrapper error is returned
+    /// * if there is an error when obtaining random numbers from the local machine
     pub fn create_key(
         &mut self,
         key_params: KeyParams,
@@ -147,8 +148,12 @@ impl TransientKeyContext {
         }
         let key_auth = if auth_size > 0 {
             self.set_session_attrs()?;
-            let random_bytes = self.context.get_random(auth_size)?;
-            Some(Auth::try_from(random_bytes.value().to_vec())?)
+            let mut random_bytes = vec![0u8; auth_size];
+            getrandom::getrandom(&mut random_bytes).map_err(|_| {
+                log::error!("Failed to obtain a random authvalue for key creation");
+                Error::WrapperError(ErrorKind::InternalError)
+            })?;
+            Some(Auth::try_from(random_bytes)?)
         } else {
             None
         };
@@ -393,6 +398,12 @@ impl TransientKeyContext {
         Ok(key_material)
     }
 
+    /// Gets the name of the root key of the TransientKeyContext
+    pub fn get_root_key_name(&mut self) -> Result<Name> {
+        let obj_handle: ObjectHandle = self.root_key_handle.into();
+        self.context.tr_get_name(obj_handle)
+    }
+
     /// Sets the encrypt and decrypt flags on the main session used by the context.
     ///
     /// # Errors
@@ -637,7 +648,7 @@ impl TransientKeyContextBuilder {
     /// Bootstrap the TransientKeyContext.
     ///
     /// The root key is created as a primary key in the provided hierarchy and thus authentication is
-    /// needed for said hierarchy. The authentication valuei for the key is generated by the TPM itself,
+    /// needed for said hierarchy. The authentication value for the key is generated locally in the machine,
     /// with a configurable length, and never exposed outside the context.
     ///
     /// # Warning
@@ -650,9 +661,9 @@ impl TransientKeyContextBuilder {
     /// * `root_key_auth_size` must be at most 32
     ///
     /// # Errors
-    /// * errors are returned if any method calls return an error: `Context::get_random`,
-    /// `Context::start_auth_session`, `Context::create_primary`, `Context::flush_context`,
-    /// `Context::set_handle_auth`
+    /// * errors are returned if any method calls return an error: `Context::start_auth_session`
+    /// `Context::create_primary`, `Context::flush_context`, `Context::set_handle_auth`
+    /// or if an internal error occurs when getting random numbers from the local machine
     /// * if the root key authentication size is given greater than 32 or if the root key size is
     /// not 1024, 2048, 3072 or 4096, a `InvalidParam` wrapper error is returned
     pub fn build(mut self) -> Result<TransientKeyContext> {
@@ -665,8 +676,12 @@ impl TransientKeyContextBuilder {
         let mut context = Context::new(self.tcti_name_conf)?;
 
         let root_key_auth = if self.root_key_auth_size > 0 {
-            let random = context.get_random(self.root_key_auth_size)?;
-            Some(Auth::try_from(random.value().to_vec())?)
+            let mut random = vec![0u8; self.root_key_auth_size];
+            getrandom::getrandom(&mut random).map_err(|_| {
+                log::error!("Failed to obtain a random value for root key authentication");
+                Error::WrapperError(ErrorKind::InternalError)
+            })?;
+            Some(Auth::try_from(random)?)
         } else {
             None
         };
