@@ -3,13 +3,20 @@
 # Copyright 2019 Contributors to the Parsec project.
 # SPDX-License-Identifier: Apache-2.0
 
-# This script executes static checks and tests for the tss-esapi crate.
+# This script executes tests for the tss-esapi crate.
 # It can be run inside the container which Dockerfile is in the same folder.
 #
 # Usage: ./tests/all.sh
 
 set -euf -o pipefail
 
+if [[ ! -z ${USE_FROZEN_LOCKFILE:+x} ]]; then
+	# Some versions of Fedora that are used during testing are old
+    # so in order to prevent any drift from the versions available
+    # in the old versions the frozen Cargo lock is used.
+	cp tests/Cargo.lock.frozen ../Cargo.lock
+fi
+
 ############################
 # Run the TPM SWTPM server #
 ############################
@@ -33,11 +40,6 @@ tpm2-abrmd \
     --session \
     --flush-all &
 
-##################
-# Execute clippy #
-##################
-cargo clippy --all-targets --all-features -- -D clippy::all -D clippy::cargo
-
 ###################
 # Build the crate #
 ###################
